
/* line 11 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/index.styl */

/* line 419 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/vendor.styl */

/* line 419 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/config.styl */

/* line 5 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/text/index.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/text/aliases.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/text/ellipsis.styl */

/* line 11 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/text/hide-text.styl */

/* line 3 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/reset.styl */

/* line 4 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/positions.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/clearfix.styl */

/* line 24 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/overflow.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/text/ellipsis.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/iconic.styl */

/* line 149 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/gradients.styl */

/* line 149 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/config.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/box.styl */

/* line 2 : /usr/local/ddg/www-release/node_modules/nib/lib/nib/color-image.styl */

/* line 4 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */

/* line 13 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
.invisible {
  visibility: hidden;
}

/* line 4 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */

/* line 4 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */
.k_float {
  z-index: 9999999;
  position: fixed !important;
  position: absolute;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */
.k_bottom {
  bottom: 0px;
}

/* line 13 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */
.k_right {
  right: 2px;
}

/* line 16 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */
.k_left {
  left: 0px;
}

/* line 19 : /usr/local/ddg/www-release/assets/stylus/_kympyle.styl */
.k_top {
  top: 0px;
  _top: expression(eval(document.compatMode && document.compatMode=='CSS1Compat') ? document.documentElement.scrollTop :document.body.scrollTop);
}

/* line 22 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */

/* line 7 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
html {
  color: #000;
  background: #fff;
}

/* line 11 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
body,
div,
dl,
dt,
dd,
ul,
ol,
li,
h1,
h2,
h3,
h4,
h5,
h6,
pre,
code,
form,
fieldset,
legend,
input,
button,
textarea,
select,
p,
blockquote,
th,
td {
  margin: 0;
  padding: 0;
}

/* line 15 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
table {
  border-collapse: collapse;
  border-spacing: 0;
}

/* line 19 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
fieldset,
img {
  border: 0;
}

/* line 22 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
address,
button,
caption,
cite,
code,
dfn,
em,
input,
optgroup,
option,
select,
strong,
textarea,
th,
var {
  font: inherit;
}

/* line 25 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
del,
ins {
  text-decoration: none;
}

/* line 28 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
li {
  list-style: none;
}

/* line 31 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
caption,
th {
  text-align: left;
}

/* line 34 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: 100%;
  font-weight: normal;
}

/* line 38 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
q:before,
q:after {
  content: '';
}

/* line 41 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
abbr,
acronym {
  border: 0;
  font-variant: normal;
}

/* line 45 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
sup {
  vertical-align: baseline;
}

/* line 48 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
sub {
  vertical-align: baseline;
}

/* line 51 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
legend {
  color: #000;
}

/* line 54 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
body {
  font: 13px/1.231 arial, helvetica, clean, sans-serif;
  *font-size: small;
  *font: x-small;
}

/* line 59 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
select,
input,
textarea,
button {
  font: 99% arial, helvetica, clean, sans-serif;
}

/* line 62 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
table {
  font-size: inherit;
  font: 100%;
}

/* line 65 : /usr/local/ddg/www-release/assets/stylus/_reset.styl */
pre,
code,
kbd,
samp,
tt {
  font-family: monospace;
  *font-size: 108%;
  line-height: 100%;
}

/* line 16 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/*
html
body
  // http://stackoverflow.com/questions/2977550/iphone-safari-css-rotation-bug
  // 2012.01.15 causes major issues with chrome people on regular browsers
  //  not being able to zoom, so ditching.
  -webkit-text-size-adjust:none
*/

/* line 25 : /usr/local/ddg/www-release/assets/stylus/style.styl */
html {
  height: 101%;
  background: #fdfdfd;
  color: #333;
  overflow-y: scroll;
  overflow-x: hidden;
}

/* line 32 : /usr/local/ddg/www-release/assets/stylus/style.styl */
body {
  font-size: 105%;
  overflow-x: hidden;
}

/* line 37 : /usr/local/ddg/www-release/assets/stylus/style.styl */
input,
body,
a,
select,
#special_page_header,
#zero_click_header,
#search_form_input,
#bang {
  font-family: "Helvetica Neue", "Segoe UI", "Nimbus Sans L", "Liberation Sans", "Open Sans", FreeSans, Arial, sans-serif;
}

/* line 48 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a {
  text-decoration: none;
  color: #1168cc;
}

/* line 51 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a:visited {
  color: #6830bb;
}

/* line 54 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a:hover,
a:focus {
  text-decoration: underline;
}

/* line 59 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a:focus {
  outline: none;
}

/* line 63 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.large {
  font-size: 128.6%;
}

/* line 66 : /usr/local/ddg/www-release/assets/stylus/style.styl */
h1,
h2,
h3,
h4,
h5,
h6 {
  display: inline;
}

/* line 74 : /usr/local/ddg/www-release/assets/stylus/style.styl */
h1 {
  font-weight: bold;
}

/* line 77 : /usr/local/ddg/www-release/assets/stylus/style.styl */
h2 {
  font-weight: normal;
}

/* line 80 : /usr/local/ddg/www-release/assets/stylus/style.styl */
img {
  display: block;
  -ms-interpolation-mode: bicubic;
}

/* line 84 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* list elements -- used on bang page */

/* line 85 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul {
  padding-left: 30px;
  padding-top: 3px;
}

/* line 89 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul li {
  list-style: disc outside;
}

/* line 92 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ol {
  padding-left: 37px;
  padding-top: 3px;
}

/* line 96 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ol li {
  list-style: decimal outside;
}

/* line 99 : /usr/local/ddg/www-release/assets/stylus/style.styl */
sup,
sub {
  height: 0;
  line-height: 1;
  vertical-align: baseline;
  _vertical-align: bottom;
  position: relative;
  font-size: 71.4%;
}

/* line 108 : /usr/local/ddg/www-release/assets/stylus/style.styl */
sup {
  bottom: 1ex;
}

/* line 111 : /usr/local/ddg/www-release/assets/stylus/style.styl */
sub {
  top: 0.5ex;
}

/* line 114 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* IDS */

/* line 116 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* for prettier rounded corners */

/* line 117 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_homepage,
#search_form_input,
#search_wrapper,
#search_wrapper_homepage {
  -moz-background-clip: padding;
  -webkit-background-clip: padding-box;
  -webkit-background-clip: padding ;
  -moz-background-clip: padding ;
  background-clip: padding-box;
}

/* line 123 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* matches resize function in js */

/* line 124 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_wrapper,
#header_content_wrapper {
  max-width: 1027px;
  min-width: 647px;
}

/* line 129 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* special page means like category page */

/* line 130 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header,
#zero_click_header {
  *zoom: 1;
  color: #444;
  background-color: #f5f5f5;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #f5f5f5), color-stop(1, #e9e9e9));
  background: -webkit-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -moz-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -o-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -ms-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  -webkit-box-shadow: inset 0 1px 0 #fbfbfb;
  -moz-box-shadow: inset 0 1px 0 #fbfbfb;
  box-shadow: inset 0 1px 0 #fbfbfb;
  -webkit-border-radius: 3px 3px 0 0;
  -moz-border-radius: 3px 3px 0 0;
  border-radius: 3px 3px 0 0;
  font-size: 107.1%;
  border-bottom: 1px solid #d1d1d1;
  padding: 0 0 0 15px;
  min-height: 36px;
  line-height: 36px;
  font-weight: bold;
  position: relative;
}

/* line 5 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#special_page_header:before,
#zero_click_header:before,
#special_page_header:after,
#zero_click_header:after {
  content: "";
  display: table;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#special_page_header:after,
#zero_click_header:after {
  clear: both;
}

/* line 144 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header.highlight,
#zero_click_header.highlight {
  -webkit-border-radius: 3px 3px 0 0 !important;
  -moz-border-radius: 3px 3px 0 0 !important;
  border-radius: 3px 3px 0 0 !important;
  border-top: none !important;
  border-left: none !important;
  border-right: none !important;
}

/* line 150 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header.min,
#zero_click_header.min {
  height: 36px;
  overflow: hidden;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  position: relative;
}

/* line 155 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header.min .icon_zero_click_header,
#zero_click_header.min .icon_zero_click_header {
  display: none;
}

/* line 157 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header.min .icon_zero_click_header#zero_click_plus_wrapper,
#zero_click_header.min .icon_zero_click_header#zero_click_plus_wrapper {
  display: block;
  position: absolute;
  top: 0;
  right: 0;
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
}

/* line 164 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header #zero_click_plus_wrapper.icon_zero_click_header,
#zero_click_header #zero_click_plus_wrapper.icon_zero_click_header {
  height: 36px;
  padding: 0 !important;
  position: absolute;
  top: 0;
  right: 0;
}

/* line 172 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_header {
  padding-right: 39px;
  height: 36px;
  overflow: hidden;
}

/* line 174 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header,
#zero_click_header h1 a,
#special_page_header h1 a {
  color: #434343;
  font-weight: bold;
}

/* line 179 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header {
  border: 1px solid #d1d1d1;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}

/* line 182 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header #zero_click_plus_wrapper {
  display: none;
}

/* line 185 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#bang_wrapper {
  max-width: 900px;
  min-width: 520px;
  margin: 0 auto;
  padding: 0 0 0 160px;
}

/* line 192 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#bang {
  position: fixed;
  width: 175px;
  top: 43px;
  left: 373px;
  display: none;
  outline: 0;
  font-size: 83.3%;
  z-index: 100;
}

/* line 203 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#bang option:hover {
  background: #86cbf4;
  color: #000;
}

/* line 208 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* used on category pages so top anchors scroll to right place */

/* line 209 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#bottom_spacing {
  clear: both;
  padding-bottom: 775px;
}

/* line 214 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* spacing at the bottom for other pages */

/* line 215 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#bottom_spacing2 {
  clear: both;
  padding-bottom: 225px;
}

/* line 220 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* padding right matches resize function in js */

/* line 221 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_wrapper {
  position: relative;
  z-index: 1;
  padding-top: 15px;
  padding-right: 50px;
}

/* line 228 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* min-width matches resize function in js */

/* line 229 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content {
  max-width: 900px;
  min-width: 520px;
  padding: 50px 0px 0px 62px;
  padding-top: expression("50px");
  _width: expression("600px");
}

/* line 237 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_homepage {
  padding-top: 10px;
  margin: auto;
  max-width: 600px;
}

/* line 243 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* for about and other pages */

/* line 244 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal {
/*padding-left: 15px;*/
  font-size: 95.2%;
}

/* line 249 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_wrapper_homepage {
  margin: auto;
  max-width: 600px;
}

/* line 254 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#did_you_mean {
  padding-bottom: 5px;
  padding-left: 33px;
  border: 1px solid #fff;
  padding-top: 10px;
  padding-bottom: 10px;
}

/* line 262 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#error_homepage {
  clear: both;
  padding-top: 20px;
  font-weight: bold;
  color: #f00;
  text-align: center;
  margin: auto;
  display: none;
}

/* line 272 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#feedback_wrapper {
  display: none;
/*
  padding-top:15px;
  padding-bottom:4px;
*/
}

/* line 280 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#feedback {
  background: url("http://duckduckgo.com/assets/icon_feedback.v101.png") no-repeat;
  -webkit-background-size: 71px 57px;
  -moz-background-size: 71px 57px;
  -o-background-size: 71px 57px;
  background-size: 71px 57px;
  cursor: pointer;
  height: 19px;
  width: 71px;
  float: left;
  margin-right: 5px;
}

/* line 289 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#feedback:hover {
  background-position: 0 -19px;
}

/* line 292 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#feedback:active {
  background-position: 0 -38px;
}

/* line 296 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage {
  vertical-align: middle;
  color: #333;
  background: #fbfbfb;
  border-top: 1px solid #e5e5e5;
  bottom: 0px;
  font-size: 13px;
  left: 0px;
  padding-top: 7px;
  padding-bottom: 7px;
  position: fixed;
  width: 100%;
}

/* line 310 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_left {
  float: left;
  padding-left: 0px;
  color: #747474;
}

/* line 316 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_left a {
  color: #747474;
  border-right: 1px dotted #999;
  height: 27px;
  padding-right: 10px;
  padding-left: 10px;
}

/* line 324 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right {
  float: right;
  padding-right: 15px;
}

/* line 329 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right a {
  color: #747474;
  border-left: 1px dotted #999;
  height: 27px;
  padding-left: 10px;
}

/* line 336 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap {
  position: absolute;
  top: 37px;
  left: auto;
  right: 1px;
  float: right;
}

/* line 343 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_homepage .bangwrap {
  position: relative;
  top: -1px;
}

/* line 344 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap ul {
  -webkit-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  list-style: none;
  float: left;
  background: #fff;
  border: 1px solid #ddd;
  margin: 0 0 0 -17px;
  padding: 0;
  font-size: 83.3%;
  min-width: 165px;
  max-height: 365px;
  overflow: auto;
}

/* line 358 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap ul.show {
  display: block;
}

/* line 360 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap li {
  margin: 0;
  padding: 0;
  color: #fff;
  display: block;
  list-style: none;
  float: none;
  height: auto;
  font-weight: normal;
}

/* line 371 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap li.header {
  background-color: #f7f7f7;
  color: #3f4651 !important;
  letter-spacing: 1px;
  font-size: 78.6%;
  border-top: 1px dotted #d1d3d6;
  border-bottom: 1px dotted #d1d3d6;
  padding-top: 6px;
  padding-bottom: 6px;
  padding-left: 7px;
  padding-right: 10px;
  font-weight: bold !important;
  cursor: default;
  text-transform: uppercase;
}

/* line 387 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap li a {
  color: #1168cc;
  display: block;
  padding-bottom: 3px;
  padding-top: 2px;
  padding-left: 5px;
  margin: 1px;
  background-color: #fff;
}

/* line 397 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bangwrap li a:hover,
.bangwrap li a:focus {
  background-color: #1258ae;
  color: #fff;
  font-weight: bold;
  text-decoration: none;
}

/* line 403 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* more menu for homepage */

/* line 404 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#more_menu {
/*box-shadow: 0 1px 3px 0 rgba(0,0,0, 0.3);  */
  border: 1px solid #c2c2c2;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  display: none;
  list-style: none;
  float: left;
  position: absolute;
  bottom: 25px;
  left: auto;
  right: 1px;
  background: #fff;
  margin: 0;
  padding: 0;
  text-align: left;
  font-size: 13px;
  z-index: 25;
}

/* line 424 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#more_menu li {
  margin: 0;
  padding: 0;
  color: #fff;
  display: block;
  list-style: none;
  float: none;
  height: auto;
  font-weight: normal;
}

/* line 433 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#more_menu li.more_menu_header {
  background-color: #f7f7f7;
  color: #3f4651 !important;
  letter-spacing: 1px;
  font-size: 78.6%;
  border-top: 1px dotted #d1d3d6;
  border-bottom: 1px dotted #d1d3d6;
  padding-top: 6px;
  padding-bottom: 6px;
  padding-left: 20px;
  padding-right: 40px;
  font-weight: bold !important;
  cursor: default;
}

/* line 447 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#more_menu li a {
  color: #1168cc;
  display: block;
  padding-bottom: 3px;
  padding-top: 2px;
  padding-left: 18px;
  margin: 1px;
  background-color: #fff;
}

/* line 455 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#more_menu li a:hover,
#more_menu li a:focus {
  background-color: #1258ae;
  color: #fff;
  font-weight: bold;
}

/* line 463 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right #more_menu {
  margin: 0 5px 20px -17px;
}

/* line 465 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right #more_menu:after,
#footer_homepage_right #more_menu:before {
  display: block;
  position: absolute;
  z-index: 0;
  content: "";
  width: 0;
  height: 0;
  right: 15px;
  border-left: 9px solid transparent;
  border-right: 9px solid transparent;
  border-bottom: 0;
}

/* line 477 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right #more_menu:before {
  bottom: -10px;
  border-top: 9px solid #c2c2c2;
}

/* line 481 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right #more_menu:after {
  bottom: -8px;
  border-top: 9px solid #fff;
}

/* line 485 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage_right #more_menu a {
  border-left: none;
  height: 19px;
  text-decoration: none;
}

/* line 488 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper {
  *zoom: 1;
  display: none;
  position: fixed;
  z-index: 2;
  left: 0;
  right: 0;
  top: 0;
  width: 100%;
}

/* line 5 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#header_wrapper:before,
#header_wrapper:after {
  content: "";
  display: table;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#header_wrapper:after {
  clear: both;
}

/* line 497 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header {
  background: url("http://duckduckgo.com/assets/header_bg.v102.png") repeat-x;
  height: 57px;
/*min-width 560px*/
  width: 100%;
}

/* line 502 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 503 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content {
  max-width: 900px;
/* min-width: 803px; removed Apr 30,2013 to fix a display bug on Android - Doug */
  margin: 0;
  padding-left: 85px;
}

/* line 508 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_logo {
  float: left;
  width: 40px;
  height: 57px;
  margin: 0px 0px -100px -80px;
  background: url("http://duckduckgo.com/assets/logo_header.v101.png") no-repeat;
  -webkit-background-size: 40px 57px;
  -moz-background-size: 40px 57px;
  -o-background-size: 40px 57px;
  background-size: 40px 57px;
}

/* line 515 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_logo img {
  width: 98px;
  height: 141px;
}

/* line 518 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper {
  float: left;
  font-weight: normal;
  font-size: 83.3%;
  margin-left: 40px;
  margin-top: 7px;
/*width: 70px*/
}

/* line 525 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper ul {
  padding: 0;
}

/* line 527 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button {
  background: url("http://duckduckgo.com/assets/header_button_bg.v101.png") repeat-x;
  border: 1px solid #b24d26;
  border-bottom: 1px solid #ca5945;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  height: 37px;
  list-style: none;
  margin: 0 auto;
  cursor: pointer;
}

/* line 536 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button:active {
  background-position: 0 -37px;
}

/* line 538 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button li {
  display: block;
  list-style: none;
  float: left;
  margin: 0 !important;
  height: 19px;
}

/* line 544 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button a {
  display: block;
  margin: 0 2px;
  border: 1px solid transparent;
  border-bottom: 0;
  padding: 2px 3px 3px;
  color: #2b68b3;
}

/* line 551 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper {
  position: relative;
/*#header_button_menu:after
                content: "-";
                font-size: 1px;
                display: block;
                position: absolute;
                opacity: 0;*/
}

/* line 553 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 554 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper a.header_button_menu_item {
  outline: none;
  background: url("http://duckduckgo.com/assets/header_button_triangle.v101.png") no-repeat;
  background-position: right 15px;
  -webkit-background-size: 8px 7px;
  -moz-background-size: 8px 7px;
  -o-background-size: 8px 7px;
  background-size: 8px 7px;
  color: #fff;
  cursor: pointer;
  height: 18px;
  margin-top: 0px;
  margin-right: 7px;
  padding-left: 7px;
  padding-right: 15px;
  padding-top: 8px;
  padding-bottom: 10px;
  text-align: right;
  text-align: center;
  text-shadow: #85361f 0px -1px;
}

/* line 571 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper a:hover,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper a:focus {
  text-decoration: none !important;
}

/* line 574 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 576 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:hover #header_button_menu,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:focus #header_button_menu,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:hover a,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:focus a {
  color: #1168cc !important;
}

/* line 580 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:hover #header_button_menu.header_button_menu_item,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:focus #header_button_menu.header_button_menu_item,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:hover a.header_button_menu_item,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper:focus a.header_button_menu_item {
  color: #fff !important;
}

/* line 582 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu {
  display: none;
  left: 50%;
  margin: 0;
  position: absolute;
  background: #fff;
  border: 1px solid #ddd;
  min-width: 114px;
  margin-left: -57px;
  margin-top: 0px;
  margin-right: 0px;
  -webkit-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
}

/* line 594 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu li {
  display: block;
  list-style: none;
  float: none;
  height: auto;
  font-weight: normal;
}

/* line 600 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu li.header_button_menu_header {
  background-color: #f7f7f7;
  color: #3f4651 !important;
  letter-spacing: 1px;
  font-size: 78.6%;
  border-top: 1px dotted #d1d3d6;
  border-bottom: 1px dotted #d1d3d6;
  padding-top: 6px;
  padding-bottom: 6px;
  padding-left: 7px;
  padding-right: 10px;
  font-weight: bold !important;
  cursor: default;
}

/* line 613 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu a {
  display: block;
  padding-bottom: 3px;
  padding-top: 2px;
  padding-left: 5px;
  margin: 1px;
  background-color: #fff;
}

/* line 620 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu a:hover,
#header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper #header_button_menu a:focus {
  background-color: #1258ae;
  color: #fff !important;
  font-weight: bold;
}

/* line 632 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* hidden iframe for html posting */

/* line 633 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#iframe_hidden {
  height: 0;
  width: 0;
  display: none;
}

/* line 639 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#keyboard_shortcuts {
  clear: both;
  width: 150px;
}

/* line 644 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#links_wrapper {
  max-width: 759px;
}

/* line 648 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* width matches resize function in js */

/* line 649 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#links {
  padding-top: 15px;
  width: 86.5%;
}

/* line 653 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#ads,
#did_you_means {
  width: 86.5%;
}

/* line 656 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#did_you_means {
  display: none;
  padding-top: 20px;
}

/* line 660 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-width: 480px) {

/* line 661 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #ads {
    height: auto !important;
  }
}

/* line 666 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* prevents outlining of keyboard shortcut links. */

/* line 667 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#links a:focus {
/* 2011.01.11 turning off so you can tab through results */
  outline: none;
  text-decoration: none;
}

/* line 674 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#loading {
  margin-left: 29px;
}

/* line 678 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* for about pages */

/* line 679 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#logo_internal {
  background: url("http://duckduckgo.com//assets/logo_words.v101.png") no-repeat left 10px;
  -webkit-background-size: 300px 45px;
  -moz-background-size: 300px 45px;
  -o-background-size: 300px 45px;
  background-size: 300px 45px;
  height: 63px;
}

/* line 684 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-device-width: 600px) {

/* line 686 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #content_homepage #logo_homepage {
    background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.normal.png");
    background-image: url("http://duckduckgo.com//assets/logo_homepage_mobile.normal.v101.png");
    -webkit-background-size: 275px 62px;
    -moz-background-size: 275px 62px;
    -o-background-size: 275px 62px;
    background-size: 275px 62px;
    width: 275px;
    height: 62px;
  }
}

/* line 694 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#logo_homepage {
  background: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage.normal.png") no-repeat center top;
  background: url("http://duckduckgo.com//assets/logo_homepage.normal.v102.png") no-repeat center top;
  -webkit-background-size: 202px 160px;
  -moz-background-size: 202px 160px;
  -o-background-size: 202px 160px;
  background-size: 202px 160px;
  margin: auto;
  padding-bottom: 1px;
  margin-bottom: 40px;
  margin-top: 40px;
  height: 161px;
  text-align: center;
  color: transparent;
  text-indent: -9999px;
  font-size: 0px;
  width: 202px;
}

/* line 709 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#logo_homepage.mobile {
  background: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.normal.png") no-repeat center top;
  background: url("http://duckduckgo.com//assets/logo_homepage_mobile.normal.png") no-repeat center top;
  -webkit-background-size: 275px 62px;
  -moz-background-size: 275px 62px;
  -o-background-size: 275px 62px;
  background-size: 275px 62px;
  width: 275px;
  height: 62px;
}

/* line 717 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#official_site {
  padding-top: 3px;
}

/* line 721 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_powered_by_wrapper {
  width: 173px;
}

/* line 725 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#powered_by {
  cursor: default;
  clear: right;
  text-align: left;
  color: #777;
  padding: 10px;
  padding-top: 12px;
  padding-right: 10px;
  background-color: #fcfcfc;
  width: 153px;
  font-size: 12px;
}

/* line 738 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#powered_by a {
  color: #777;
}

/* line 742 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#powered_by img {
  float: right;
}

/* line 747 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* holds hidden params tied to search box */

/* line 748 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_elements_hidden {
  display: none;
  height: 0;
}

/* line 753 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* search_form* widths must match resize function in JS */

/* line 754 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form {
  float: left;
/* matches duckduck.js and one more pixel to not break firefox zoom level */
  width: 554px;
  margin-left: -25px;
  border-bottom: 1px solid #cc6a5f;
  border-left: 0px solid #e37552;
  border-top: 0px solid #ec9a77;
  border-right: 0px solid #e37552;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  margin-top: 7px;
  position: relative;
}

/* line 770 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_homepage {
  width: 518px;
  margin: auto;
  text-align: left;
  position: relative;
  z-index: 0;
}

/* line 776 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_homepage:after {
  content: "";
  display: table;
  clear: both;
}

/* line 783 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_dropdown {
  display: block;
  float: left;
  width: 24px;
  height: 37px;
  background: url("http://duckduckgo.com/assets/search_dropdown.v102.png");
  -webkit-background-size: 67px 74px;
  -moz-background-size: 67px 74px;
  -o-background-size: 67px 74px;
  background-size: 67px 74px;
  background-position: top right;
  outline: none;
}

/* line 793 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_dropdown:active {
  background-position: right bottom;
}

/* line 796 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* keeping this visible even for non-js so that the page doesn't flicker when we add it back
   possibly a better way to hide it though.
*/

/* line 799 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_dropdown_homepage {
  display: block;
  float: left;
  width: 23px;
  height: 40px;
  background: url("http://duckduckgo.com/assets/search_dropdown_homepage.v102.png") no-repeat;
  -webkit-background-size: 67px 78px;
  -moz-background-size: 67px 78px;
  -o-background-size: 67px 78px;
  background-size: 67px 78px;
  background-position: top right;
}

/* line 809 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_dropdown_homepage:active {
  background-position: right bottom;
}

/* line 813 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input {
  position: absolute;
  top: 0;
  left: 0;
  float: right;
  background: #fff;
  color: #222;
  width: 446px;
  height: 27px;
  padding: 4px 6px 4px 8px;
  margin: 0;
  outline: none;
  border: 1px solid #835342;
  border-right: 0;
  font-size: 95.2%;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  -webkit-border-top-left-radius: 3px;
  -webkit-border-bottom-left-radius: 3px;
/* for IE10 */
/* firefox focus */
/* webkit focus */
}

/* line 832 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input::-ms-clear {
  display: none;
}

/* line 833 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input:-moz-placeholder {
  color: #a1a1a1;
}

/* line 834 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input::-webkit-input-placeholder {
  color: #a1a1a1;
}

/* line 837 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_homepage {
  position: relative;
  right: 67px;
  z-index: 2;
  float: right;
  background: #fff;
  color: #222;
  width: 430px;
  height: 28px;
  padding: 4px 6px 5px 6px;
  margin: 0;
  outline: none;
  border-right: 0;
  border: 1px solid #8d8d8d;
  font-size: 18px;
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  -webkit-border-top-left-radius: 3px;
  -webkit-border-bottom-left-radius: 3px;
  -webkit-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 1px 1px 2px #999;
  -webkit-box-shadow: inset 1px 1px 2px #999;
  -moz-box-shadow: inset 1px 1px 2px #999;
  box-shadow: inset 1px 1px 2px #999;
/* for IE10 */
}

/* line 861 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.no-menu #search_form_input_homepage {
  right: 0;
}

/* line 862 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_homepage::-ms-clear {
  display: none;
}

/* line 865 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_wrapper {
  float: right;
  width: 67px;
  height: 37px;
hidden
}

/* line 872 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_wrapper_homepage {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 3;
  float: right;
  height: 39px;
  width: 67px;
  background: #2db750;
  overflow: hidden;
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  -webkit-border-top-right-radius: 3px;
  -webkit-border-bottom-right-radius: 3px;
  -webkit-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 0 1px 2px 0 rgba(0,0,0,0.20);
}

/* line 889 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.no-menu #search_wrapper_homepage {
  position: relative;
}

/* line 894 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_clear {
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  float: right;
  width: 27px;
  border: 0;
  background: #fff url("http://duckduckgo.com/assets/icon_xon.v102.png") no-repeat 2px center;
  -webkit-background-size: 18px 18px;
  -moz-background-size: 18px 18px;
  -o-background-size: 18px 18px;
  background-size: 18px 18px;
  cursor: pointer;
  height: 27px;
  *height: 37px;
  margin: 0;
  padding: 4px 0;
  outline: none;
  border: none;
/* ie7 */
  *border-left: #fff solid 1px;
  *border-right: #fff solid 1px;
  border-bottom: #835342 solid 1px;
  border-top: #835342 solid 1px;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}

/* line 916 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_clear:active {
  background-image: url("http://duckduckgo.com/assets/icon_xoff.v102.png");
  -webkit-background-size: 18px 18px;
  -moz-background-size: 18px 18px;
  -o-background-size: 18px 18px;
  background-size: 18px 18px;
}

/* line 920 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_form_input_clear.empty {
  background-position: -100px 0;
}

/* line 924 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_button {
  float: left;
  height: 37px;
  width: 43px;
  border: 0;
  background: url("http://duckduckgo.com/assets/search_dropdown.v102.png");
  -webkit-background-size: 67px 74px;
  -moz-background-size: 67px 74px;
  -o-background-size: 67px 74px;
  background-size: 67px 74px;
  cursor: pointer;
  outline: none;
}

/* line 935 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_button:active {
  background-position: 0 -37px;
}

/* line 939 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_button_homepage {
  float: left;
  height: 39px;
  width: 44px;
  border: 0;
/*background:url(http://duckduckgo.com/'/sbutton.v101.green.png') no-repeat;*/
  background: url("http://duckduckgo.com/assets/search_dropdown_homepage.v102.png") no-repeat;
  -webkit-background-size: 67px 78px;
  -moz-background-size: 67px 78px;
  -o-background-size: 67px 78px;
  background-size: 67px 78px;
  cursor: pointer;
}

/* line 950 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#search_button_homepage:active {
  background-position: 0 -39px;
}

/* line 954 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_wrapper {
  max-width: 759px;
  display: none;
  position: relative;
  margin: 0;
  padding: 0;
}

/* line 962 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* width matches resize function in js */

/* line 963 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_wrapper2 {
  width: 150px;
  position: absolute;
  right: -100px;
  top: 18px;
  font-size: 71.4%;
  color: #545454;
}

/* line 972 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side {
  background-color: #fcfcfc;
  position: fixed;
  width: 150px;
  z-index: 1;
  margin-top: 0px;
}

/* line 980 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_map {
  padding-bottom: 20px;
}

/* line 984 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_sponsored {
  text-align: left;
}

/* line 988 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_suggestions {
  text-align: left;
  padding-left: 2px;
  font-size: 12px;
}

/* line 994 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side_suggestions a {
  color: #777;
}

/* line 998 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* #spacing_hidden_wrapper {} */

/* line 1000 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#spacing_hidden {
  height: 0;
  display: none;
  float: left;
  font-size: 83.3%;
  padding-bottom: 40px;
}

/* line 1008 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* holds last clicked element to highlight on back */

/* line 1009 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#state_hidden {
  height: 0;
  border: 0;
  width: 0;
  display: none;
}

/* line 1016 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#tagline_homepage {
  color: #747474;
  margin: auto;
  text-align: center;
  font-size: 14px;
  padding-top: 45px;
}

/* line 1024 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_wrapper2 {
  overflow-y: auto;
  min-height: 30px;
}

/* line 1029 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_wrapper {
  padding-top: 20px;
  max-width: 759px;
  display: block;
}

/* line 1035 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* width matches resize function in js */

/* line 1036 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click {
  background: #fff;
  border: 1px solid #c9c9c9;
  border-color: rgba(136,136,136,0.48);
  width: 86.5%;
  -moz-border-radius: 3px;
  -webkit-border-radius: 3px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  z-index: 10;
}

/* line 1047 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click blockquote {
  margin: 8px 0px 12px 15px;
  padding: 5px 5px 1px;
  border-left: 2px solid #808080;
}

/* line 1053 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click blockquote,
q {
  quotes: none;
}

/* line 1057 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click p {
  clear: both;
  margin-bottom: 5px;
}

/* line 1062 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click pre {
  background-color: #eee;
  color: #333;
  font-family: Consolas, Menlo, Monaco, Lucida Console, Liberation Mono, DejaVu Sans Mono, Bitstream Vera Sans Mono, Courier New, monospace, serif;
  margin-bottom: 5px;
  padding: 5px;
  margin-right: 10px;
  word-wrap: break-word;
  white-space: pre-wrap;
/* css-3 */
  white-space: -moz-pre-wrap;
/* Mozilla, since 1999 */
  white-space: -pre-wrap;
/* Opera 4-6 */
  white-space: -o-pre-wrap;
/* Opera 7 */
}

/* line 1076 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper {
  overflow: hidden;
  margin-left: 14px;
  margin-right: 10px;
}

/* line 1081 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper,
#zero_click_plus_wrapper a {
  float: right;
  width: 16px;
  top: 0px;
  text-align: right;
  text-decoration: none !important;
  padding-bottom: 2px;
/* minimize on http://yegg.duckduckgo.com/?q=C3O5 */
}

/* line 1090 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus {
  -webkit-tap-highlight-color: transparent;
  background: url("http://duckduckgo.com/assets/icon_minus.v104.png") center top no-repeat;
  -webkit-background-size: 16px 72px;
  -moz-background-size: 16px 72px;
  -o-background-size: 16px 72px;
  background-size: 16px 72px;
  height: 36px;
  margin: -3px 0 -7px;
}

/* line 1097 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus:active {
  background-position: center bottom;
}

/* line 1100 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus.plus {
  background: url("http://duckduckgo.com/assets/icon_plus.v104.png") center top no-repeat;
  -webkit-background-size: 16px 72px;
  -moz-background-size: 16px 72px;
  -o-background-size: 16px 72px;
  background-size: 16px 72px;
}

/* line 1104 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus.plus:active {
  background-position: center bottom;
}

/* line 1108 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_abstract,
#zero_click_abstract_stacked {
  font-size: 83.3%;
  line-height: 1.4;
  word-wrap: break-word;
  border: 1px solid #f9f9f9;
  border-color: rgba(0,0,0,0.00);
  padding: 2px;
  margin: 2px;
  margin-top: 4px;
  padding-top: 0px;
  margin-bottom: 2px;
}

/* line 1121 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_answer {
  margin-left: 25px;
}

/* line 1125 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_heading {
  float: left;
  margin-top: 0px;
  margin-bottom: 0px;
}

/* line 1131 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_header_info {
  padding-top: 10px;
  padding-left: 65px;
  font-size: 77.8%;
}

/* line 1137 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_image {
  float: right;
  max-width: 95% !important;
  margin-top: 10px;
  margin-left: 15px;
  margin-right: 10px;
  padding-bottom: 10px;
  padding-right: 3px;
  line-height: 1.2;
  font-size: 83.3%;
  text-align: center;
}

/* line 1148 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_image img {
  max-width: 100% !important;
  height: auto !important;
}

/* line 1149 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_image.nofloat {
  float: none;
  margin: 0 auto;
  padding-top: 10px;
}

/* line 1150 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_image.nofloat + #zero_click_abstract {
  max-width: 100% !important;
}

/* line 1152 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_image.nofloat + #zero_click_abstract br {
  display: none;
  visibility: hidden;
}

/* line 1155 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media screen and (max-width: 500px) {

/* line 1156 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_image.zci_big {
    float: none;
    clear: both;
    margin: 0 auto;
    padding-top: 10px;
  }

/* line 1161 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_image.zci_big img {
    margin: 0 auto;
  }

/* line 1163 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_image.zci_big + #zero_click_abstract {
    margin-right: 10px !important;
    clear: both;
  }
}

/* line 1165 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_more_at_link {
  display: inline-block;
}

/* line 1168 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_more_at_link img {
  margin-bottom: -2px;
}

/* line 1171 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/*
.zero_click_more_at_link {
  clear: both;
  display: block;
  float: right;
  padding: 0 0 7px;
}
.zero_click_more_at_link + a img.icon_spice, .zero_click_more_at_link a img, .zero_click_more_at_link + .icon_spice {
  float: right; 
}
a + .zero_click_more_at_link { clear: none; float: none; display: inline; }
*/

/* line 1184 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* like safe search filter message */

/* line 1185 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_message {
  padding-left: 35px;
  font-size: 83.3%;
  padding-bottom: 0px;
  padding-top: 15px;
}

/* line 1192 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_topics {
  font-size: 83.3%;
  margin-left: 10px;
  margin-bottom: 4px;
}

/* line 1198 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_more_at_logo {
  display: inline;
  height: 15px;
  margin-left: 5px;
}

/* line 1205 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* ADD TO BROWSER/MODALS */

/* line 1207 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal,
.add_to_browser,
#footer_homepage .add_to_browser,
#footer_homepage .modal {
  min-height: 50px;
  width: 185px;
  background-color: #fff;
  border: 1px solid #c2c2c2;
  display: none;
  position: absolute;
  bottom: 25px;
  left: -10px;
  text-align: left;
  padding: 13px 7px 18px 18px;
  margin: 10px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  z-index: 1000;
  font-size: 14px;
  -webkit-box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
  -webkit-box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
  -moz-box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
  box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
}

/* line 1226 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal:after,
.add_to_browser:after,
#footer_homepage .add_to_browser:after,
#footer_homepage .modal:after,
.modal:before,
.add_to_browser:before,
#footer_homepage .add_to_browser:before,
#footer_homepage .modal:before {
  display: block;
  position: absolute;
  z-index: -1;
  content: "";
  width: 0;
  height: 0;
  left: 50px;
  border-left: 9px solid transparent;
  border-right: 9px solid transparent;
  border-bottom: 0;
}

/* line 1238 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal:before,
.add_to_browser:before,
#footer_homepage .add_to_browser:before,
#footer_homepage .modal:before {
  bottom: -10px;
  border-top: 9px solid #c2c2c2;
}

/* line 1242 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal:after,
.add_to_browser:after,
#footer_homepage .add_to_browser:after,
#footer_homepage .modal:after {
  bottom: -8px;
  border-top: 9px solid #fff;
}

/* line 1246 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal h4,
.add_to_browser h4,
#footer_homepage .add_to_browser h4,
#footer_homepage .modal h4 {
  color: #444;
  margin: 0 0 16px !important;
  font-size: 15px;
  font-weight: bold;
  display: block;
}

/* line 1247 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon,
.add_to_browser a.icon,
#footer_homepage .add_to_browser a.icon,
#footer_homepage .modal a.icon,
.modal .icon,
.add_to_browser .icon,
#footer_homepage .add_to_browser .icon,
#footer_homepage .modal .icon {
  display: block;
  position: relative;
  padding: 0 0 0 18px;
  font-size: 13px;
  height: auto;
  line-height: 1;
  margin: 14px 0 0;
  border: none;
}

/* line 1256 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon:hover,
.add_to_browser a.icon:hover,
#footer_homepage .add_to_browser a.icon:hover,
#footer_homepage .modal a.icon:hover,
.modal .icon:hover,
.add_to_browser .icon:hover,
#footer_homepage .add_to_browser .icon:hover,
#footer_homepage .modal .icon:hover,
.modal a.icon a:hover,
.add_to_browser a.icon a:hover,
#footer_homepage .add_to_browser a.icon a:hover,
#footer_homepage .modal a.icon a:hover,
.modal .icon a:hover,
.add_to_browser .icon a:hover,
#footer_homepage .add_to_browser .icon a:hover,
#footer_homepage .modal .icon a:hover {
  text-decoration: none;
  color: #666;
}

/* line 1257 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon:before,
.add_to_browser a.icon:before,
#footer_homepage .add_to_browser a.icon:before,
#footer_homepage .modal a.icon:before,
.modal .icon:before,
.add_to_browser .icon:before,
#footer_homepage .add_to_browser .icon:before,
#footer_homepage .modal .icon:before {
  position: absolute;
  left: 0;
  top: 0;
  color: #adaaac;
  font-weight: bold;
  display: block;
  float: left;
}

/* line 1258 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon.add:before,
.add_to_browser a.icon.add:before,
#footer_homepage .add_to_browser a.icon.add:before,
#footer_homepage .modal a.icon.add:before,
.modal .icon.add:before,
.add_to_browser .icon.add:before,
#footer_homepage .add_to_browser .icon.add:before,
#footer_homepage .modal .icon.add:before {
  content: "\002B";
  font-size: 16px;
  top: -2px;
}

/* line 1259 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon.more:before,
.add_to_browser a.icon.more:before,
#footer_homepage .add_to_browser a.icon.more:before,
#footer_homepage .modal a.icon.more:before,
.modal .icon.more:before,
.add_to_browser .icon.more:before,
#footer_homepage .add_to_browser .icon.more:before,
#footer_homepage .modal .icon.more:before {
  content: "\2026";
  font-size: 12px;
  top: -1px;
}

/* line 1260 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon.try:before,
.add_to_browser a.icon.try:before,
#footer_homepage .add_to_browser a.icon.try:before,
#footer_homepage .modal a.icon.try:before,
.modal .icon.try:before,
.add_to_browser .icon.try:before,
#footer_homepage .add_to_browser .icon.try:before,
#footer_homepage .modal .icon.try:before {
  content: "\21BA";
  font-size: 14px;
  top: 1px;
  left: -2px;
}

/* line 1261 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon.bad:before,
.add_to_browser a.icon.bad:before,
#footer_homepage .add_to_browser a.icon.bad:before,
#footer_homepage .modal a.icon.bad:before,
.modal .icon.bad:before,
.add_to_browser .icon.bad:before,
#footer_homepage .add_to_browser .icon.bad:before,
#footer_homepage .modal .icon.bad:before {
  content: "\2639";
  font-size: 16px;
  top: -1px;
  left: -2px;
}

/* line 1262 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon.ques:before,
.add_to_browser a.icon.ques:before,
#footer_homepage .add_to_browser a.icon.ques:before,
#footer_homepage .modal a.icon.ques:before,
.modal .icon.ques:before,
.add_to_browser .icon.ques:before,
#footer_homepage .add_to_browser .icon.ques:before,
#footer_homepage .modal .icon.ques:before {
  content: "\003F";
  font-size: 12px;
  top: 1px;
  left: 2px;
}

/* line 1264 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal .icon,
.add_to_browser .icon,
#footer_homepage .add_to_browser .icon,
#footer_homepage .modal .icon {
  color: #666;
}

/* line 1265 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.modal a.icon,
.add_to_browser a.icon,
#footer_homepage .add_to_browser a.icon,
#footer_homepage .modal a.icon,
.modal .icon a,
.add_to_browser .icon a,
#footer_homepage .add_to_browser .icon a,
#footer_homepage .modal .icon a {
  color: #1168cc;
}

/* line 1267 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.trig_add_browser,
.modal_trig {
  position: relative;
  display: inline-block;
  width: 1px;
  height: 0px;
}

/* line 1274 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage #trig_add_to_browser_homepage .add_to_browser,
#footer_homepage #trig_add_to_browser_homepage .modal {
  left: -113px;
}

/* line 1276 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#footer_homepage #trig_add_to_browser_homepage .add_to_browser:after,
#footer_homepage #trig_add_to_browser_homepage .modal:after,
#footer_homepage #trig_add_to_browser_homepage .add_to_browser:before,
#footer_homepage #trig_add_to_browser_homepage .modal:before {
  left: 150px;
}

/* line 1279 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .add_to_browser,
#side .modal {
  font-weight: normal;
  left: auto;
  right: 34px;
  bottom: auto;
  top: -43px;
}

/* line 1285 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .add_to_browser:after,
#side .modal:after,
#side .add_to_browser:before,
#side .modal:before {
  left: auto;
  bottom: auto;
  top: 20px;
  border-top: 9px solid transparent;
  border-bottom: 9px solid transparent;
  border-right: 0;
}

/* line 1293 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .add_to_browser:before,
#side .modal:before {
  right: -10px;
  border-left: 9px solid #c2c2c2;
}

/* line 1297 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .add_to_browser:after,
#side .modal:after {
  right: -8px;
  border-left: 9px solid #fff;
}

/* line 1303 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side #side_map.border {
  width: 100%;
}

/* line 1305 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side #side_map.border img {
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}

/* line 1308 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .border,
#side .button {
  padding: 1px;
  color: #686771;
  background: #f5f5f5;
  margin-bottom: 7px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  position: relative;
  cursor: pointer !important;
}

/* line 1317 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button {
  font-size: 11px;
  font-weight: bold;
  line-height: 1;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #f5f5f5), color-stop(1, #e9e9e9));
  background: -webkit-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -moz-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -o-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -ms-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  padding: 10px 4px 9px 31px;
  width: 138px;
}

/* line 1325 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button:hover,
#side .border:hover {
  background: #fff;
}

/* line 1328 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button:active {
  background-color: #eee;
}

/* line 1331 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* extra selectors to get around some quirkiness */

/* line 1332 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .border,
#side .button,
#side #feedback_wrapper .button {
  border: 1px solid #c9c9c9;
}

/* line 1334 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button-link {
  border: none;
  color: #686771;
  text-decoration: none !important;
}

/* line 1340 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button .button-link {
  padding: 10px 4px 9px 31px;
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 80%;
}

/* line 1349 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* icons for specific items */

/* line 1350 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side .button .trig_add_browser + a:before,
#side .button .add-to:before {
  content: "";
  width: 16px;
  height: 16px;
  position: absolute;
  top: 8px;
  left: 8px;
  background: url("http://duckduckgo.com/assets/icon_plus.v103.png") no-repeat left 0;
  -webkit-background-size: 16px 34px;
  -moz-background-size: 16px 34px;
  -o-background-size: 16px 34px;
  background-size: 16px 34px;
}

/* line 1360 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#side #feedback_wrapper .button:before {
  content: "";
  width: 20px;
  height: 17px;
  position: absolute;
  top: 7px;
  left: 6px;
  background: url("http://duckduckgo.com/assets/icon_feedback.v103.png") no-repeat left 0;
  -webkit-background-size: 20px 17px;
  -moz-background-size: 20px 17px;
  -o-background-size: 20px 17px;
  background-size: 20px 17px;
}

/* line 1371 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* CLASSES */

/* line 1373 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.anchor {
  display: inline-block;
  position: relative;
  bottom: 50px;
  height: 0;
  width: 0;
  margin: 0;
  float: left;
}

/* line 1383 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.clear {
  clear: both;
  height: 0;
  font-size: 0;
  line-height: 0;
}

/* line 1390 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.hide {
  display: none;
}

/* line 1394 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.hidden {
  display: none;
}

/* line 1398 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.help,
.warning,
.info,
.untranslated {
  padding: 12px;
  color: #333;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  font-size: 0.9em;
  -webkit-box-shadow: inset 0 1px 1px rgba(255,255,255,0.50), 0 1px 1px rgba(0,0,0,0.10);
  -moz-box-shadow: inset 0 1px 1px rgba(255,255,255,0.50), 0 1px 1px rgba(0,0,0,0.10);
  box-shadow: inset 0 1px 1px rgba(255,255,255,0.50), 0 1px 1px rgba(0,0,0,0.10);
}

/* line 1404 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.help:hover,
.warning:hover,
.info:hover,
.untranslated:hover {
  -webkit-box-shadow: 0 1px 5px rgba(0,0,0,0.10);
  -moz-box-shadow: 0 1px 5px rgba(0,0,0,0.10);
  box-shadow: 0 1px 5px rgba(0,0,0,0.10);
}

/* line 1406 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.info {
  background: #fef9cd;
  border: 1px solid #e1d980;
}

/* line 1407 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.help,
.untranslated {
  background: #cde1fe;
  border: 1px solid #8099e1;
}

/* line 1408 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.warning {
  background: #fecdcd;
  border: 1px solid #e18080;
}

/* line 1410 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#special_page_header + .untranslated,
#zero_click_header + .untranslated,
#special_page_header + .info,
#zero_click_header + .info,
.untranslated + .clu,
.untranslated + .info,
.untranslated + .help,
.untranslated + .warning {
  margin-top: 14px;
}

/* line 1412 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* comes before so highlight can control it */

/* line 1413 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#ads .highlight_sponsored {
  background: #fff7d0;
  background: rgba(255,212,0,0.18);
  border: 1px solid #fef9eb;
  border-color: rgba(255,212,0,0.08);
  -moz-border-radius: 6px;
  -webkit-border-radius: 6px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  margin-bottom: 1px;
}

/* line 1424 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#ads .highlight_sponsored.highlight_sponsored_hover {
  background: #fffced;
  background: rgba(255,212,0,0.10);
  border-color: rgba(255,212,0,0.40);
}

/* line 1430 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.highlight,
#links .highlight,
#zero_click .highlight,
#did_you_means .highlight {
  cursor: pointer !important;
  border: 1px solid #eaeaea;
  border-color: rgba(136,136,136,0.17);
}

/* line 1435 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.highlight {
  -moz-border-radius: 6px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: inset 0 1px 0 rgba(255,255,255,0.10);
  -moz-box-shadow: inset 0 1px 0 rgba(255,255,255,0.10);
  box-shadow: inset 0 1px 0 rgba(255,255,255,0.10);
/* background: #EAEAEA url(http://duckduckgo.com/assets/results_highlight_bg.v101.png) repeat-x;  
  background: linear-gradient(top,#f4f4f4 0,#eaeaea 100%); */
  background: #f3f3f3;
}

/* line 1442 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.highlight:active {
  opacity: 0.9;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=90);
}

/* line 1445 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click .highlight {
  -moz-border-radius: 3px;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  background: #f6f6f6;
  background: rgba(127,127,127,0.04);
  border: 1px solid #e5e5e5;
}

/* line 1453 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/*
#zero_click .highlight {
  box-shadow: 1px 1px 3px rgba(136,136,136,0.5);
}
*/

/* line 1458 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.highlight_zero_click_wrapper {
  border: 1px solid #f9f9f9;
  padding: 2px;
}

/* line 1463 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons {
  text-align: center;
  padding: 19px 0 39px;
}

/* line 1466 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons .button {
  padding: 0 10px;
  min-width: 116px;
  height: 36px;
  line-height: 36px;
  color: #7b7b7b;
  background: #fafafa;
  font-size: 12px;
  border: 1px solid #dedede;
  border-left-style: none;
  border-right-style: dotted;
  -webkit-box-shadow: inset 0 1px 0 #fff;
  -moz-box-shadow: inset 0 1px 0 #fff;
  box-shadow: inset 0 1px 0 #fff;
  display: inline-block;
}

/* line 1479 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons .button.first {
  -webkit-border-radius: 3px 0 0 3px;
  -moz-border-radius: 3px 0 0 3px;
  border-radius: 3px 0 0 3px;
  border-left: 1px solid #dedede;
}

/* line 1483 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons .button.last {
  -webkit-border-radius: 0 3px 3px 0;
  -moz-border-radius: 0 3px 3px 0;
  border-radius: 0 3px 3px 0;
  border-right-style: solid;
}

/* line 1487 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons .button:hover {
  text-decoration: none;
  background: #fff;
}

/* line 1489 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons #more_menu {
  bottom: -5px;
}

/* line 1491 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons #more_menu:after,
.homepage-buttons #more_menu:before {
  display: block;
  position: absolute;
  z-index: 0;
  content: "";
  width: 0;
  height: 0;
  bottom: 67px;
  border-top: 9px solid transparent;
  border-bottom: 9px solid transparent;
  border-left: 0;
}

/* line 1503 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons #more_menu:before {
  left: -10px;
  border-right: 9px solid #c2c2c2;
}

/* line 1507 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-buttons #more_menu:after {
  left: -9px;
  border-right: 9px solid #f7f7f7;
}

/* line 1513 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.homepage-message {
  text-align: center;
  font-size: 12px;
}

/* line 1517 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.horizontal_line {
  height: 1px;
  margin: 0;
  padding: 0;
  border: none;
  color: #bade89;
  background-color: #d2d2d2;
  background-color: rgba(136,136,136,0.39);
  text-align: left;
}

/* line 1528 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.horizontal_line_truncated {
  width: 85%;
}

/* line 1532 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav,
.icon_fav2,
.icon_category,
.icon_disambig {
  float: left;
  display: none;
}

/* line 1537 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_category {
  width: 53px;
  text-align: center;
}

/* line 1542 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header,
#zero_click_plus_wrapper.icon_zero_click_header {
  position: absolute;
  float: right;
  display: inline-block;
  margin: 0;
  padding: 0;
  width: 39px;
  height: 100%;
  border-left: 1px solid #c8c8c8;
  -webkit-box-shadow: inset 1px 0 0 #fbfbfb;
  -moz-box-shadow: inset 1px 0 0 #fbfbfb;
  box-shadow: inset 1px 0 0 #fbfbfb;
  background-color: #f5f5f5;
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #f5f5f5), color-stop(1, #e9e9e9));
  background: -webkit-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -moz-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -o-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: -ms-linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
  background: linear-gradient(top, #f5f5f5 0, #e9e9e9 100%);
}

/* line 1554 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header a,
#zero_click_plus_wrapper.icon_zero_click_header a {
  float: none;
  display: block;
  text-align: center;
  margin-left: auto;
  margin-right: auto;
  width: 100%;
}

/* line 1561 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 1562 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header a[title="HQ Images"] img,
#zero_click_plus_wrapper.icon_zero_click_header a[title="HQ Images"] img,
.icon_zero_click_header a[title="Definition"] img,
#zero_click_plus_wrapper.icon_zero_click_header a[title="Definition"] img {
  top: 5px;
}

/* line 1565 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header:hover,
#zero_click_plus_wrapper.icon_zero_click_header:hover {
  background: #fff;
}

/* line 1566 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header img,
#zero_click_plus_wrapper.icon_zero_click_header img {
  position: relative;
}

/* line 1567 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_header #zero_click_plus,
#zero_click_plus_wrapper.icon_zero_click_header #zero_click_plus {
  margin-top: 0;
  height: 100%;
}

/* line 1569 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper.icon_zero_click_header + .icon_zero_click_header {
  right: 40px;
}

/* line 1572 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper.icon_zero_click_header + .icon_zero_click_header  + .icon_zero_click_header {
  right: 80px;
}

/* line 1575 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper.icon_zero_click_header + .icon_zero_click_header  + .icon_zero_click_header + .icon_zero_click_header {
  right: 120px;
}

/* line 1578 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper.icon_zero_click_header + .icon_zero_click_header  + .icon_zero_click_header + .icon_zero_click_header + .icon_zero_click_header {
  right: 160px;
}

/* line 1581 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#zero_click_plus_wrapper.icon_zero_click_header + .icon_zero_click_header  + .icon_zero_click_header + .icon_zero_click_header + .icon_zero_click_header + .icon_zero_click_header {
  right: 200px;
}

/* line 1585 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav3,
.icon_spice {
  display: inline;
  float: left;
  padding-right: 5px;
  width: 16px;
  height: 16px;
}

/* line 1593 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_spice {
  padding-top: 2px;
}

/* line 1597 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_spice_inline {
  display: inline;
  padding-left: 1px;
  padding-right: 3px;
  width: 16px;
  height: 16px;
  text-align: center;
  position: relative;
  top: 2px;
}

/* line 1608 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_disambig {
  height: 100%;
  width: 38px;
  text-align: center;
  margin: 0;
  vertical-align: middle;
  position: absolute;
  top: 0;
  left: 0;
  padding-right: 8px;
}

/* line 1618 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_disambig:before {
  display: inline-block;
  height: 100%;
  width: 1px;
  content: " ";
  vertical-align: middle;
}

/* line 1627 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav img,
.icon_fav2 img,
.icon_category img,
.icon_disambig img {
  visibility: hidden;
}

/* line 1631 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav img,
.icon_fav2 img {
  width: 16px;
  height: 16px;
}

/* line 1636 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav img,
.icon_category img {
  padding-top: 5px;
}

/* line 1640 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_category img,
.icon_disambig img {
  display: inline;
  vertical-align: middle;
}

/* line 1645 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav2 img {
  padding-top: 5px;
}

/* line 1649 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_fav2 a + a img {
  margin-bottom: -21px;
}

/* line 1653 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.icon_zero_click_answer {
  float: left;
  padding-top: 6px;
  padding-left: 8px;
  padding-right: 10px;
  display: inline;
}

/* line 1661 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.img_badge {
  display: inline;
  position: relative;
  top: 2px;
  vertical-align: top;
}

/* line 1668 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.img_category {
  max-height: 50px;
  max-width: 50px;
  width: expression("50px");
}

/* line 1674 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.img_disambig {
  max-height: 30px;
  max-width: 30px;
  width: expression("30px");
}

/* line 1680 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.img_zero_click {
  max-height: 100px;
  max-width: 100px;
  width: expression("100px");
}

/* line 1686 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* For things like xkcd */

/* line 1687 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.img_zero_click_big {
  max-width: 85%;
  margin: auto;
  margin-bottom: 5px;
  margin-top: 5px;
}

/* line 1694 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.inline {
  display: inline;
}

/* line 1698 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_deep,
.links_main,
.links_more {
  font-size: 83.3%;
}

/* line 1702 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_indent {
  padding-left: 35px;
}

/* line 1706 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_main {
  text-align: left;
  margin-left: 30px;
  word-wrap: break-word;
  *zoom: 1;
}

/* line 5 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
.links_main:before,
.links_main:after {
  content: "";
  display: table;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
.links_main:after {
  clear: both;
}

/* line 1711 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 1712 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_main div a.hidden {
  display: inline;
  visibility: hidden !important;
}

/* line 1716 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.sponsored_info {
  font-size: 85.7%;
  color: #555 !important;
  float: right;
  padding-right: 20px;
  padding-left: 10px;
}

/* line 1724 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu,
.links_menu a {
  background: url("http://duckduckgo.com/assets/icon_triangle.v101.png") no-repeat 95% 5px;
  -webkit-background-size: 6px 7px;
  -moz-background-size: 6px 7px;
  -o-background-size: 6px 7px;
  background-size: 6px 7px;
  font-size: 85.7%;
  color: #555 !important;
  float: right;
  padding-right: 20px;
  padding-left: 10px;
}

/* line 1733 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#links .links_menu {
  float: none;
}

/* line 1735 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_wrapper {
  width: 200px;
  display: inline;
  overflow: hidden;
  position: relative;
}

/* line 1742 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_wrapper:hover,
.links_menu_wrapper:focus {
  overflow: visible;
}

/* line 1746 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_items {
  margin: 0;
  float: left;
  position: absolute;
  top: -20px;
  left: -2000px;
  display: block;
  background: #fff;
  border: 1px solid #ddd;
  margin-left: 2px;
  margin-top: -1px;
  margin-right: 0px;
  -moz-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -webkit-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  -moz-box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  box-shadow: 0 1px 3px 0 rgba(0,0,0,0.20);
  width: 150px;
  text-align: left;
}

/* line 1765 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_wrapper:hover .links_menu_items,
.links_menu_wrapper:focus .links_menu_items {
  left: 20px;
}

/* line 1769 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_items:after {
  content: "-";
  font-size: 1px;
  display: block;
  position: fixed;
  opacity: 0;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);
}

/* line 1777 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_items li {
  display: block;
  list-style: none;
  float: none;
  height: auto;
  font-weight: normal;
}

/* line 1785 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_menu_items a {
  display: block;
  padding: 2px 3px;
  margin: 0;
  background-color: #fff;
}

/* line 1792 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_more {
  text-align: left;
  margin-left: 58px;
  word-wrap: break-word;
}

/* line 1798 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_type {
  font-size: 65%;
}

/* line 1802 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_zero_click {
  text-align: left;
  padding-left: 5px;
  margin-right: 5px;
  word-wrap: break-word;
}

/* line 1809 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.links_zero_click_disambig {
  text-align: left;
  margin-right: 10px;
  padding: 6px 0 2px 47px;
  word-wrap: break-word;
  border: 1px solid transparent;
  min-height: 24px;
}

/* line 1818 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.page_count {
  float: left;
  color: #555;
  font-size: 71.4%;
  text-align: left;
}

/* line 1825 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.page_count_pre,
.page_count_post {
  color: #fff;
  background-color: #fff;
  border: 1px dotted #777;
  border-style: none none dotted;
  height: 1px;
  text-align: right;
  float: left;
}

/* line 1835 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.page_count_pre {
  width: 10%;
}

/* line 1839 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.page_count_post {
  width: 70%;
}

/* line 1843 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_links,
.results_zero_click,
.results_disambig,
.results_links_more,
.results_category_more,
.results_disambig_more {
  clear: left;
  padding-top: 10px;
  padding-bottom: 10px;
  border: 1px solid #fcfcfc;
}

/* line 1850 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_links_deep {
  padding-left: 5px;
  padding-top: 10px;
  padding-bottom: 10px;
  border: 1px solid #fcfcfc;
}

/* line 1857 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_links {
  padding-left: 5px;
}

/* line 1861 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_links_more {
  padding-left: 33px;
}

/* line 1865 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_category_more {
  padding-left: 63px;
}

/* line 1869 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_disambig_more {
  margin-right: 10px;
  padding: 6px 0 2px 47px;
  position: relative;
  min-height: 22px;
}

/* line 1876 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_zero_click,
.results_zero_click_more {
  padding-bottom: 3px;
  padding-top: 3px;
  border: 1px solid transparent;
}

/* line 1882 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_disambig_more,
.results_disambig {
  border: 1px solid transparent;
}

/* line 1886 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_disambig {
  padding-bottom: 0px;
  padding-top: 0px;
  min-height: 30px;
  position: relative;
}

/* line 1893 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_zero_click {
  clear: none;
  padding-top: 3px;
}

/* line 1898 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.results_zero_click_more {
  padding-top: 3px;
  padding-left: 5px;
  font-size: 90%;
}

/* line 1904 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.search_suggestion,
.bang_suggestion {
  line-height: 1.4;
  cursor: pointer !important;
  margin-bottom: 7px;
  width: 150px;
  font-size: 12px;
}

/* line 1912 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.search_suggestion a {
  background: url("http://duckduckgo.com/assets/icon_plus.v102.png") no-repeat left center;
  -webkit-background-size: 12px 12px;
  -moz-background-size: 12px 12px;
  -o-background-size: 12px 12px;
  background-size: 12px 12px;
  padding-left: 14px;
}

/* line 1918 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bang_suggestion a {
  padding-left: 10px;
  white-space: nowrap;
  word-wrap: break-word;
  text-overflow: ellipsis;
  line-height: 1;
  height: 1em;
  width: 124px;
  overflow: hidden;
  display: inline-block;
}

/* line 1930 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.bang_suggestion img {
  margin-top: 0px;
  float: left;
}

/* line 1935 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.small {
  font-size: 83.3%;
}

/* line 1939 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.snippet,
.snippet a {
  clear: both;
  line-height: 1.4;
  color: #333 !important;
  text-decoration: none !important;
}

/* line 1946 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* if move in a you can get a double size reduction */

/* line 1947 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.snippet {
  font-size: 92.8%;
}

/* line 1951 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.spacer_bottom_7 {
  padding-bottom: 7px;
}

/* line 1955 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.spacer_bottom_10 {
  padding-bottom: 10px;
}

/* line 1959 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.spacer_top_3 {
  padding-top: 3px;
}

/* line 1963 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.spacer_top_10 {
  padding-top: 10px;
}

/* line 1967 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.url,
.url a {
  color: #781900 !important;
  font-size: 92.8%;
}

/* line 1972 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_auto {
  margin: 0 auto !important;
}

/* line 1976 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_answer {
  padding-left: 5px !important;
  margin-left: 30px !important;
  margin-right: 50px !important;
}

/* line 1982 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_header_info {
  font-style: normal;
}

/* line 1986 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_snippet {
  padding: 10px;
  padding-top: 5px;
  padding-bottom: 3px;
  padding-left: 5px !important;
  margin-left: 10px !important;
}

/* line 1994 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.zero_click_snippet_no_image {
  padding: 0px;
  padding-bottom: 5px;
  margin-left: 10px !important;
  padding-left: 5px !important;
}

/* line 2001 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.feedback_form_error {
  margin-top: 15px;
  padding: 3px;
  background: #fef9cd;
  border: #e1d980 1px solid;
  display: none;
}

/* line 2009 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.share-button,
a.share-button {
  text-transform: uppercase;
  position: relative;
  background: #eee;
  background: #eee -webkit-gradient(linear, left top, left bottom, color-stop(0, rgba(255,255,255,0.10)), color-stop(1, rgba(0,0,0,0.10)));
  background: #eee -webkit-linear-gradient(top, rgba(255,255,255,0.10) 0, rgba(0,0,0,0.10) 100%);
  background: #eee -moz-linear-gradient(top, rgba(255,255,255,0.10) 0, rgba(0,0,0,0.10) 100%);
  background: #eee -o-linear-gradient(top, rgba(255,255,255,0.10) 0, rgba(0,0,0,0.10) 100%);
  background: #eee -ms-linear-gradient(top, rgba(255,255,255,0.10) 0, rgba(0,0,0,0.10) 100%);
  background: #eee linear-gradient(top, rgba(255,255,255,0.10) 0, rgba(0,0,0,0.10) 100%);
  border: 1px solid #aaa;
  border-top: 1px solid #ccc;
  border-left: 1px solid #ccc;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
  color: #444;
  display: inline-block;
  font-size: 11px;
  font-weight: bold;
  text-decoration: none;
  text-shadow: 0 1px rgba(255,255,255,0.75);
  cursor: pointer;
  line-height: 16px;
  padding: 4px 4px 4px 20px;
}

/* line 2027 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.share-button:before,
a.share-button:before {
  display: block;
  content: "";
  position: absolute;
  top: 50%;
  left: 4px;
  width: 12px;
  height: 12px;
  margin-top: -6px;
  background: url("http://duckduckgo.com//assets/icon_share.v101.png") 0 0 no-repeat;
}

/* line 2030 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.share-button:hover,
a.share-button:hover {
  color: #222;
  background: #ddd -webkit-gradient(linear, left top, left bottom, color-stop(0, rgba(255,255,255,0.20)), color-stop(1, rgba(0,0,0,0.20)));
  background: #ddd -webkit-linear-gradient(top, rgba(255,255,255,0.20) 0, rgba(0,0,0,0.20) 100%);
  background: #ddd -moz-linear-gradient(top, rgba(255,255,255,0.20) 0, rgba(0,0,0,0.20) 100%);
  background: #ddd -o-linear-gradient(top, rgba(255,255,255,0.20) 0, rgba(0,0,0,0.20) 100%);
  background: #ddd -ms-linear-gradient(top, rgba(255,255,255,0.20) 0, rgba(0,0,0,0.20) 100%);
  background: #ddd linear-gradient(top, rgba(255,255,255,0.20) 0, rgba(0,0,0,0.20) 100%);
  border: 1px solid #888;
  border-top: 1px solid #aaa;
  border-left: 1px solid #aaa;
  text-decoration: none;
}

/* line 2036 : /usr/local/ddg/www-release/assets/stylus/style.styl */
.share-button:active,
a.share-button:active {
  border: 1px solid #666;
  background: #ccc -webkit-gradient(linear, left top, left bottom, color-stop(0, rgba(255,255,255,0.25)), color-stop(1, rgba(10,10,10,0.40)));
  background: #ccc -webkit-linear-gradient(top, rgba(255,255,255,0.25) 0, rgba(10,10,10,0.40) 100%);
  background: #ccc -moz-linear-gradient(top, rgba(255,255,255,0.25) 0, rgba(10,10,10,0.40) 100%);
  background: #ccc -o-linear-gradient(top, rgba(255,255,255,0.25) 0, rgba(10,10,10,0.40) 100%);
  background: #ccc -ms-linear-gradient(top, rgba(255,255,255,0.25) 0, rgba(10,10,10,0.40) 100%);
  background: #ccc linear-gradient(top, rgba(255,255,255,0.25) 0, rgba(10,10,10,0.40) 100%);
}

/* line 2042 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon {
  background-image: url("http://duckduckgo.com//assets/sharesprite.v101.png");
  width: 181px;
  height: 39px;
  display: block;
  float: left;
  cursor: pointer;
  text-indent: -9999px;
}

/* line 2050 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.facebook,
a.shareon.twitter {
  margin-right: 13px;
}

/* line 2051 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.facebook {
  background-position: 0 0;
  margin-left: 1px;
}

/* line 2052 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon:hover {
  background-position: 0 79px;
}

/* line 2053 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon:hover:active {
  background-position: 0 39px;
}

/* line 2055 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.twitter {
  background-position: 363px 0;
}

/* line 2056 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.twitter:hover {
  background-position: 363px 79px;
}

/* line 2057 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.twitter:active {
  background-position: 363px 39px;
}

/* line 2059 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.email {
  background-position: 181px 0;
}

/* line 2060 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.email:hover {
  background-position: 181px 79px;
}

/* line 2061 : /usr/local/ddg/www-release/assets/stylus/style.styl */
a.shareon.email:active {
  background-position: 181px 39px;
}

/* line 2065 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* static page stuff goes here */

/* line 2066 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2067 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal h1,
#content_internal h2,
#content_internal h3,
#content_internal h4,
#content_internal h5,
#content_internal h6 {
  font-weight: normal;
  position: relative;
  clear: both;
  display: block;
  margin: 2.5em auto 1.5em;
}

/* line 2074 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal h2 {
  color: #c63934;
  font-size: 20px;
  font-weight: normal;
  display: block;
  margin: 68px 0 20px;
  padding: 0;
  line-height: 1.1;
  clear: both;
  letter-spacing: 0.05em;
}

/* line 2085 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal h2 a {
  color: inherit;
}

/* line 2087 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal p,
#content_internal ul {
  margin: 1.5em auto;
  line-height: 1.25;
}

/* line 2088 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal ul li {
  margin-bottom: 7px;
}

/* line 2089 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal ul.no-bul {
  list-style: none;
  padding-left: 0;
}

/* line 2090 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#content_internal ul.no-bul li {
  list-style: none;
}

/* line 2093 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2094 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #logo_internal {
  background-position: 50% 10px;
}

/* line 2095 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback h1,
#pg-feedback h3,
#pg-feedback .mid {
  text-align: center;
}

/* line 2096 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .headline {
  margin: -10px auto 60px 75px;
  font-size: 36px;
  color: #666;
}

/* line 2097 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest {
  background-color: #fff;
  border: 1px solid #c2c2c2;
  padding: 13px 7px 18px 18px;
  margin: 10px;
  -moz-border-radius: 4px;
  -webkit-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
  z-index: 1000;
  font-size: 14px;
  -webkit-box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
  -moz-box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
  box-shadow: 0px 0px 6px 0px rgba(0,0,0,0.20);
}

/* line 2108 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest img {
  max-width: 100%;
  margin: 0 auto 10px;
  display: block;
}

/* line 2109 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest ul {
  font-size: 85%;
  padding-right: 10px;
  max-width: 290px;
}

/* line 2110 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest ul li {
  margin-bottom: 7px;
  color: #333;
}

/* line 2111 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest a {
  color: inherit;
  display: block;
  overflow: hidden;
  padding: 20px 0;
}

/* line 2112 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest a:hover {
  text-decoration: none;
  -webkit-border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}

/* line 2113 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest a:active {
  background: #fff;
}

/* line 2115 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback .dest:hover {
  -webkit-box-shadow: 0px 0px 12px 0px rgba(0,0,0,0.10);
  -moz-box-shadow: 0px 0px 12px 0px rgba(0,0,0,0.10);
  box-shadow: 0px 0px 12px 0px rgba(0,0,0,0.10);
  background: #f7f7f7;
}

/* line 2120 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes {
  clear: both;
}

/* line 2121 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes .dest {
  margin: 10px auto;
}

/* line 2122 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes .dest img {
  float: left;
  margin: 0 40px 0 10px;
}

/* line 2123 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes .dest h2 {
  margin-top: 5px;
  clear: none;
}

/* line 2124 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes .dest ul {
  max-width: 100%;
  font-size: 90%;
}

/* line 2125 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback #dest-boxes .dest ul li {
  list-style: square;
  list-style-position: inside;
}

/* line 2129 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback label.cap {
  display: inline-block;
  min-width: 62px;
}

/* line 2130 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-feedback input[type="submit"] {
  padding: 0 10px;
}
@media only screen and (max-width: 600px), only screen and (max-width: 46.154em) {

/* line 2133 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes {
    width: 100%;
  }

/* line 2135 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes .dest img {
    width: 80px;
    margin-top: 20px;
    margin-bottom: 40px;
  }
}
@media only screen and (max-width: 360px), only screena and (max-width: 27.692em) {

/* line 2139 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes {
    width: 95%;
  }

/* line 2140 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2141 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes .dest img {
    float: none;
    margin: 0 auto 10px;
  }

/* line 2142 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes .dest h2 {
    text-align: center;
  }

/* line 2143 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback #dest-boxes .dest ul {
    padding-left: 5px;
  }

/* line 2146 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-feedback input[type="text"],
  #pg-feedback textarea {
    width: 95%;
  }
}

/* line 2149 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2150 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-support h2,
#pg-support h3 {
  color: #c63934;
  font-weight: normal;
  display: block;
  margin: 0 0 20px;
  padding: 0;
  line-height: 1.1;
  clear: both;
  letter-spacing: 0.05em;
}

/* line 2160 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-support h2 {
  font-size: 28px;
}

/* line 2161 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-support h3 {
  font-size: 20px;
  margin-top: 40px;
}

/* line 2163 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2171 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #content_internal {
  padding-left: 3px;
}

/* line 2172 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about .text-container {
  padding-left: 20px;
}

/* line 2178 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about .video-container {
  border: 1px solid #222;
  overflow: hidden;
  position: relative;
}

/* line 2179 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about .video-container video {
  margin: 0;
}

/* line 2180 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about .video-container .share-buttons {
  position: absolute;
  top: 0;
  right: 5px;
  float: right;
  margin-top: -40px;
  -webkit-transition: all 0.25s ease-out;
  -moz-transition: all 0.25s ease-out;
  -o-transition: all 0.25s ease-out;
  -ms-transition: all 0.25s ease-out;
  transition: all 0.25s ease-out;
}

/* line 2181 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2181 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about .video-container:hover .share-buttons {
  margin-top: 5px;
}
@media only screen and (max-width: 1024px) {

/* line 2184 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about .video-container {
    overflow: visible;
  }

/* line 2185 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about .video-container .share-buttons {
    top: auto;
    right: 0;
    bottom: -33px;
    margin-top: 0 !important;
  }
}

/* line 2188 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #share-panel {
  display: none;
  border: 1px solid #ddd;
  padding: 14px 7px;
  clear: both;
  background: #eee;
  color: #444;
}

/* line 2189 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #share-panel .embed-code {
  font-family: monospace;
  margin: 7px 7px 7px 0;
  padding: 14px;
  border: 1px solid #ddd;
  background: #f2f2f2;
}

/* line 2191 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about h2 {
  font-size: 28px;
/* -- duplicated above in global static selector
    color: #c63934; 
    font-weight: normal;
    display: block; 
    margin: 68px 0 20px; 
    padding: 0; 
    line-height: 1.1; 
    clear: both; 
    letter-spacing: 0.05em; 
    */
}

/* line 2204 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about hr {
  border: none;
  outline: none;
  height: 2px;
  background: #f7faff;
  background: rgba(215,215,215,0.13);
  border-top: 1px solid #e6e6e6;
  border-top: 1px solid rgba(215,215,215,0.50);
  width: 100%;
  display: block;
  margin: 20px auto;
}

/* line 2205 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about p {
  font-size: 18px;
}

/* line 2207 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #spread {
  padding-left: 20px;
}

/* line 2208 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #spread .newsletter {
  padding-top: 25px;
}

/* line 2209 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #spread .like {
  padding-top: 20px;
}

/* line 2212 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features {
  margin-bottom: 0px;
  padding-left: 20px;
}

/* line 2213 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul {
  *zoom: 1;
  margin: 0 auto;
  padding: 0;
  list-style: none;
  width: 100%;
  max-width: 736px;
  display: block;
  overflow: visible;
}

/* line 5 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#pg-about #features ul:before,
#pg-about #features ul:after {
  content: "";
  display: table;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#pg-about #features ul:after {
  clear: both;
}

/* line 2214 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li {
  margin: 20px 0;
  padding: 0 0 0 10%;
  width: 40%;
  min-width: 222px;
  height: 50px;
  line-height: 50px;
  float: left;
  display: block;
  background-position: 0 0;
  background-repeat: no-repeat;
  list-style: none;
  font-size: 18px;
  position: relative;
}

/* line 2215 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.goodies {
  background-image: url("http://duckduckgo.com//assets/about/icon_goodies.png");
}

/* line 2216 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.goodies:hover {
  background-image: url("http://duckduckgo.com//assets/about/icon_goodies_red.png");
}

/* line 2218 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.bubble {
  background-image: url("http://duckduckgo.com//assets/about/icon_bubble.png");
}

/* line 2219 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.bubble:hover {
  background-image: url("http://duckduckgo.com//assets/about/icon_bubble_red.png");
}

/* line 2221 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.answers {
  background-image: url("http://duckduckgo.com//assets/about/icon_instant-answers.png");
}

/* line 2222 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.answers:hover {
  background-image: url("http://duckduckgo.com//assets/about/icon_instant-answers_red.png");
}

/* line 2224 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.privacy {
  background-image: url("http://duckduckgo.com//assets/about/icon_privacy.png");
}

/* line 2225 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.privacy:hover {
  background-image: url("http://duckduckgo.com//assets/about/icon_privacy_blue.png");
}

/* line 2227 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.clutter {
  background-image: url("http://duckduckgo.com//assets/about/icon_spam-clutter.png");
}

/* line 2228 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li.clutter:hover {
  background-image: url("http://duckduckgo.com//assets/about/icon_spam-clutter_blue.png");
}

/* line 2230 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li a {
  color: inherit;
  display: block;
  padding-left: 75px;
  position: relative;
  left: -75px;
  width: 110%;
}

/* line 2237 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li a:hover {
  text-decoration: none;
}

/* line 2238 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li a:hover em {
  text-decoration: underline;
}

/* line 2241 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li em {
  color: #1168cc;
  font-style: normal;
}

/* line 2242 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li * {
  -webkit-transition: all 0.5s ease-out;
  -moz-transition: all 0.5s ease-out;
  -o-transition: all 0.5s ease-out;
  -ms-transition: all 0.5s ease-out;
  transition: all 0.5s ease-out;
}

/* line 2243 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li blockquote {
  opacity: 0;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);
  position: absolute;
  visibility: hidden;
  line-height: 1.2;
  top: 80%;
  left: 10%;
  color: #fff;
  padding: 15px 20px;
  min-width: 90%;
  text-align: left;
  font-size: 18px;
  font-weight: bold;
  font-style: normal;
  font-family: sans-serif;
  display: inline-block;
  background-color: #3368ae;
  background-color: rgba(50,95,168,0.75);
}

/* line 2261 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li blockquote.noquote {
  font-style: normal;
  font-weight: bold;
  letter-spacing: -0.02em;
  font-size: 22px;
}

/* line 2263 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2264 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li:hover blockquote,
#pg-about #features ul li:active blockquote,
#pg-about #features ul li:hover img,
#pg-about #features ul li:active img {
  opacity: 1;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=100);
}

/* line 2265 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #features ul li:hover blockquote,
#pg-about #features ul li:active blockquote {
  z-index: 50;
  visibility: visible;
}
@media only screen and (max-width: 700px) {

/* line 2269 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #features ul li {
    padding: 0 0 0 75px;
  }
}

/* line 2274 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes {
  margin-bottom: 0px;
}

/* line 2275 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul {
  *zoom: 1;
  margin: 0 auto;
  padding: 0;
  list-style: none;
  width: 100%;
  display: block;
  overflow: visible;
/*
        @media only screen and (max-width: 480px) {
          li { text-align: center;
            img { max-width: 100%; float: none; position: static; }
            blockquote { padding: 10px 5%; float: none; display: block; margin: 5px auto;            
            }
            &#about, &#nyt, &#sel { img { position: static; top: 0; left: 0; } }
          }
        } 
        */
}

/* line 5 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#pg-about #quotes ul:before,
#pg-about #quotes ul:after {
  content: "";
  display: table;
}

/* line 9 : /usr/local/ddg/www-release/assets/stylus/_helpers.styl */
#pg-about #quotes ul:after {
  clear: both;
}

/* line 2276 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li {
  margin: 19px;
  padding: 0;
  height: 85px;
  position: relative;
  list-style: none;
  float: left;
  display: table-cell;
  text-align: center;
  vertical-align: middle;
  overflow: visible;
}

/* line 2287 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li:before {
  display: inline-block;
  height: 100%;
  width: 1px;
  content: " ";
  vertical-align: middle;
}

/* line 2288 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li a {
  display: inline-block;
  overflow: visible;
}

/* line 2289 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li * {
  -webkit-transition: all 0.4s ease-out;
  -moz-transition: all 0.4s ease-out;
  -o-transition: all 0.4s ease-out;
  -ms-transition: all 0.4s ease-out;
  transition: all 0.4s ease-out;
}

/* line 2290 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li img {
  vertical-align: middle;
  opacity: 0.6;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=60);
  display: inline;
  min-width: 1px;
}

/* line 2291 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote {
  opacity: 0;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);
  position: absolute;
  visibility: hidden;
  bottom: 50%;
  left: 50px;
  color: #fff;
  padding: 15px 20px;
  min-width: 90%;
  text-align: left;
  font-size: 20px;
  font-weight: bold;
  font-style: italic;
  font-family: sans-serif;
  display: inline-block;
  background-color: #3368ae;
  background-color: rgba(50,95,168,0.75);
}

/* line 2308 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote:before,
#pg-about #quotes ul li blockquote:after {
  color: #9bb4d7;
  font-size: 1.5em;
  margin-top: 0.1em;
  position: relative;
}

/* line 2309 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote:before {
  content: "\201C";
  float: left;
  text-indent: -0.8em;
  float: left;
  top: -5px;
  left: 5px;
}

/* line 2310 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote:after {
  top: 5px;
  display: inline;
  content: "\201D";
  line-height: 1px;
}

/* line 2311 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote.noquote {
  font-style: normal;
  font-weight: bold;
  letter-spacing: -0.02em;
  font-size: 22px;
}

/* line 2316 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li blockquote.noquote:before,
#pg-about #quotes ul li blockquote.noquote:after {
  display: none;
}

/* line 2319 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2320 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li:hover blockquote,
#pg-about #quotes ul li:active blockquote,
#pg-about #quotes ul li:hover img,
#pg-about #quotes ul li:active img {
  opacity: 1;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=100);
}

/* line 2321 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li:hover blockquote,
#pg-about #quotes ul li:active blockquote {
  z-index: 50;
  visibility: visible;
  left: 20px;
}

/* line 2323 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2323 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li#nyt blockquote {
  width: 400px;
}

/* line 2324 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2324 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li#tc blockquote {
  width: 420px;
}

/* line 2325 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2325 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li#sel blockquote {
  width: 350px;
}

/* line 2326 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2326 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li#wired blockquote,
#pg-about #quotes ul li#tnw blockquote {
  width: 250px;
}

/* line 2327 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2327 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#pg-about #quotes ul li#time blockquote,
#pg-about #quotes ul li#cnn blockquote,
#pg-about #quotes ul li#pc blockquote {
  width: 180px;
}
@media only screen and (min-width: 768px) {

/* line 2330 : /usr/local/ddg/www-release/assets/stylus/style.styl */
}
@media only screen and (max-width: 768px) {

/* line 2335 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li {
    text-align: left;
    width: 100%;
    height: auto;
    margin: 10px auto !important;
  }

/* line 2336 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li a {
    overflow: hidden;
    display: block;
  }

/* line 2337 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li img {
    max-width: 35%;
    float: left;
  }

/* line 2338 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li blockquote {
    position: static;
    vertical-align: middle;
    visibility: visible;
    opacity: 0.8;
    filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=80);
    float: right;
    min-width: 50%;
    max-width: 50%;
    font-size: 16px;
    padding: 10px 15px;
  }

/* line 2339 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li blockquote.noquote {
    font-size: 18px;
  }

/* line 2340 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li blockquote img {
    float: none !important;
    max-width: 100% !important;
    position: static !important;
    margin: 0 !important;
  }

/* line 2342 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2342 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li#about img,
  #pg-about #quotes ul li#nyt img,
  #pg-about #quotes ul li#sel img {
    position: absolute;
    top: 45%;
    left: 0;
  }

/* line 2343 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #pg-about #quotes ul li#nyt img {
    top: 50%;
  }
}

/* line 2360 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers {
  margin: 10px auto;
  padding: 0;
  list-style: none;
  display: block;
  overflow: hidden;
  width: 110%;
}

/* line 2362 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li {
  float: left;
  list-style: none;
  text-indent: -9999px;
  width: 66px;
  height: 66px;
  background-image: url("http://duckduckgo.com//assets/browser_logos-64.png");
  -webkit-background-size: 353px 66px;
  -moz-background-size: 353px 66px;
  -o-background-size: 353px 66px;
  background-size: 353px 66px;
  opacity: 0.8;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=80);
}

/* line 2371 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li.chrome {
  background-position: 1.5% 0;
}

/* line 2372 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li.firefox {
  background-position: 26.5% 0;
}

/* line 2373 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li.opera {
  background-position: 51.5% 0;
}

/* line 2374 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li.safari {
  background-position: 75% 0;
}

/* line 2375 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li.ie {
  background-position: 99.5% 0;
}

/* line 2376 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li:hover {
  opacity: 1;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=100);
}

/* line 2377 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li:active {
  opacity: 0.9;
  filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=90);
}

/* line 2378 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers li a {
  display: block;
  width: 100%;
  height: 132px;
}

/* line 2380 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers.big li {
  width: 132px;
  height: 132px;
  background-image: url("http://duckduckgo.com//assets/browser_logos-128.png");
  -webkit-background-size: 705px 132px;
  -moz-background-size: 705px 132px;
  -o-background-size: 705px 132px;
  background-size: 705px 132px;
}

/* line 2386 : /usr/local/ddg/www-release/assets/stylus/style.styl */
ul.browsers.small li {
  width: 33px;
  height: 33px;
  background-image: url("http://duckduckgo.com//assets/browser_logos-32.png");
  -webkit-background-size: 175px 33px;
  -moz-background-size: 175px 33px;
  -o-background-size: 175px 33px;
  background-size: 175px 33px;
}

/* line 2393 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* end static pages */

/* line 2395 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* Small screens */

/* line 2396 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* kindle fire is 600 */

/* line 2397 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-device-width: 599px) {

/* line 2399 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #content,
  #content_wrapper,
  #content_homepage,
  #content_wrapper_homepage,
  #zero_click_wrapper,
  #links_wrapper,
  #zero_click,
  #links {
    width: 97%;
    min-width: 97%;
    margin: auto;
    padding-right: 0;
  }

/* line 2405 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #content {
    margin: auto;
    padding-left: 0;
    padding-top: 50px;
    position: relative;
    left: 1px;
  }

/* line 2412 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #logo_homepage {
    padding-bottom: 20px;
    margin-bottom: 0px;
  }

/* line 2416 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #header_button_wrapper,
  #search_dropdown,
  #bang_wrapper,
  #search_dropdown_homepage {
    display: none;
  }

/* line 2419 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form {
    width: 236px;
  }

/* line 2422 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_homepage {
    width: 220px;
  }

/* line 2425 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_wrapper {
    width: 42px;
  }

/* line 2428 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_wrapper_homepage {
    width: 42px;
  }

/* line 2431 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input {
    width: 153px;
    padding-right: 9px;
  }

/* line 2435 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input_homepage {
    width: 163px;
  }
}

/* line 2441 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-device-width: 599px) and (orientation:landscape) {

/* line 2442 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form {
    width: 336px;
  }

/* line 2445 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input {
    width: 253px;
  }

/* line 2448 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_homepage {
    width: 313px;
  }

/* line 2451 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input_homepage {
    width: 253px;
  }
}

/* line 2456 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-height: 480px) {

/* line 2457 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #more_menu,
  #footer_homepage_right #more_menu {
    margin-bottom: 0;
    max-height: 320px;
    overflow-y: auto;
  }

/* line 2461 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #more_menu:after,
  #footer_homepage_right #more_menu:after,
  #more_menu:before,
  #footer_homepage_right #more_menu:before {
    display: none;
  }
}

/* line 2465 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-width: 407px) {

/* line 2466 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #header_button_wrapper {
    display: none;
  }
}

/* line 2469 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (max-width: 320px) {

/* line 2470 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2471 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_header #zero_click_heading {
    max-width: 255px;
  }

/* line 2474 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_header h1 {
    font-size: 16px;
  }
}

/* line 2481 : /usr/local/ddg/www-release/assets/stylus/style.styl */
/* source ids */

/* line 2482 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#wwo_outer {
  background: none !important;
  padding-left: 15px;
  padding-bottom: 5px;
  width: 95% !important;
}

/* line 2487 : /usr/local/ddg/www-release/assets/stylus/style.styl */
#wwo_outer td {
  display: block;
  float: left;
}

/* line 2492 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media screen and (min-width: 950px) {

/* line 2493 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table td:first-child {
    width: 275px !important;
  }
}

/* line 2497 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media screen and (max-width: 652px) {

/* line 2498 : /usr/local/ddg/www-release/assets/stylus/style.styl */

/* line 2499 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table td:first-child {
    width: 155px !important;
  }
}

/* line 2504 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media screen and (max-width: 629px) {

/* line 2505 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer {
    padding-left: 7px;
  }

/* line 2507 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table {
    margin-bottom: 10px;
  }

/* line 2509 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table td:first-child {
    float: none;
    margin-bottom: 10px;
  }

/* line 2512 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table td:not(:first-child) {
    max-width: 24%;
    margin-right: 1%;
  }

/* line 2514 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #wwo_outer table td:not(:first-child) img {
    max-width: 100%;
    height: auto !important;
    display: block;
    margin: 0 auto !important;
  }
}

/* line 2520 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (-webkit-min-device-pixel-ratio: 1.5),only screen and (-moz-min-device-pixel-ratio: 1.5),only screen and (min--moz-device-pixel-ratio: 1.5),only screen and (min-device-pixel-ratio: 1.5),only screen and (min-resolution: 96dpi) {

/* line 2528 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #content_homepage #logo_homepage.mobile {
    background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.hdpi.png");
    background-image: url("http://duckduckgo.com//assets/logo_homepage_mobile.hdpi.v101.png");
  }
@media screen and (max-device-width: 600px) {

/* line 2533 : /usr/local/ddg/www-release/assets/stylus/style.styl */
    #content_homepage #logo_homepage {
      background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.hdpi.png");
      background-image: url("http://duckduckgo.com//assets/logo_homepage_mobile.hdpi.v101.png");
    }
}

/* line 2538 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #content_homepage {
    width: 97%;
    min-width: 97%;
    margin: auto;
    padding-right: 0;
  }

/* line 2544 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_dropdown,
  .mobile #search_dropdown_homepage {
    display: none;
  }

/* line 2547 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form {
    width: 236px;
  }

/* line 2550 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form_homepage {
    width: 220px;
  }

/* line 2553 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_wrapper {
    width: 42px;
  }

/* line 2556 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_wrapper_homepage {
    width: 42px;
  }

/* line 2559 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form_input {
    width: 153px;
  }

/* line 2562 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile  #search_form_input_homepage {
    width: 163px;
  }

/* line 2565 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #header_wrapper #header #header_content_wrapper #header_content #header_logo {
    background-image: url("http://duckduckgo.com/assets/logo_header.v101.hdpi.png");
  }

/* line 2568 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #logo_internal {
    background-image: url("http://duckduckgo.com//assets/logo_words.v101.hdpi.png");
  }

/* line 2571 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_button,
  #search_dropdown {
    background-image: url("http://duckduckgo.com/assets/search_dropdown.v102.hdpi.png");
  }

/* line 2574 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_button_homepage,
  #search_dropdown_homepage {
    background-image: url("http://duckduckgo.com/assets/search_dropdown_homepage.v102.hdpi.png");
  }

/* line 2577 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_plus {
    background-image: url("http://duckduckgo.com/assets/icon_minus.v104.hdpi.png");
  }

/* line 2580 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_plus.plus {
    background-image: url("http://duckduckgo.com/assets/icon_plus.v104.hdpi.png");
  }
}

/* line 2584 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (-webkit-min-device-pixel-ratio:1.5) and (orientation:landscape) {

/* line 2585 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form {
    width: 312px;
  }

/* line 2588 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form_input {
    width: 253px;
  }

/* line 2591 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form_homepage {
    width: 352px;
  }

/* line 2594 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #search_form_input_homepage {
    width: 287px;
  }

/* line 2597 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #content {
    padding-right: 0;
  }
}

/* line 2599 : /usr/local/ddg/www-release/assets/stylus/style.styl */
@media only screen and (-webkit-min-device-pixel-ratio: 2),only screen and (-moz-min-device-pixel-ratio: 2),only screen and (min--moz-device-pixel-ratio: 2),only screen and (-ms-min-device-pixel-ratio: 2),only screen and (min-device-pixel-ratio: 2),only screen and (min-resolution: 192dpi) {

/* line 2600 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #logo_homepage {
    background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage.retina.png");
    background-image: url("http://duckduckgo.com//assets/logo_homepage.retina.v101.png");
  }

/* line 2604 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .mobile #content_homepage #logo_homepage.mobile {
    background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.retina.png");
    background-image: url("http://duckduckgo.com//assets/logo_homepage_mobile.retina.v101.png");
  }
@media screen and (max-device-width: 600px) {

/* line 2609 : /usr/local/ddg/www-release/assets/stylus/style.styl */
    #content_homepage #logo_homepage {
      background-image: url("http://duckduckgo.com//assets/logos/brahms/logo_homepage_mobile.retina.png");
      background-image: url("http://duckduckgo.com//assets/logo_homepage_mobile.retina.v101.png");
    }
}

/* line 2614 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #feedback {
    background-image: url("http://duckduckgo.com/assets/icon_feedback.v101.retina.png");
  }

/* line 2617 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .search_suggestion a {
    background-image: url("http://duckduckgo.com/assets/icon_plus.v102.retina.png");
  }

/* line 2620 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .links_menu,
  .links_menu a {
    background-image: url("http://duckduckgo.com/assets/icon_triangle.v101.retina.png");
  }

/* line 2623 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  .img_badge {
    display: inline-block;
    overflow: hidden;
    height: 0;
    width: 71px;
    padding-top: 19px;
    background: url("http://duckduckgo.com//assets/icon_official.v101.retina.png") top left no-repeat;
    -webkit-background-size: 71px 19px;
    -moz-background-size: 71px 19px;
    -o-background-size: 71px 19px;
    background-size: 71px 19px;
  }

/* line 2632 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #header_wrapper #header #header_content_wrapper #header_content #header_logo {
    background-image: url("http://duckduckgo.com/assets/logo_header.v101.retina.png") no-repeat;
  }

/* line 2635 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #header_wrapper #header #header_content_wrapper #header_content #header_button_wrapper #header_button #header_button_menu_wrapper a.header_button_menu_item {
    background-image: url("http://duckduckgo.com/assets/header_button_triangle.v101.retina.png");
  }

/* line 2638 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #logo_internal {
    background-image: url("http://duckduckgo.com//assets/logo_words.v101.retina.png");
  }

/* line 2641 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_button,
  #search_dropdown {
    background-image: url("http://duckduckgo.com/assets/search_dropdown.v102.retina.png");
  }

/* line 2644 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_button_homepage,
  #search_dropdown_homepage {
    background-image: url("http://duckduckgo.com/assets/search_dropdown_homepage.v102.retina.png");
  }

/* line 2647 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input_clear {
    background-image: url("http://duckduckgo.com/assets/icon_xon.v101.retina.png");
  }

/* line 2650 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #search_form_input_clear:active {
    background-image: url("http://duckduckgo.com/assets/icon_xoff.v101.retina.png");
  }

/* line 2653 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_plus {
    background-image: url("http://duckduckgo.com/assets/icon_minus.v104.retina.png");
  }

/* line 2656 : /usr/local/ddg/www-release/assets/stylus/style.styl */
  #zero_click_plus.plus {
    background-image: url("http://duckduckgo.com/assets/icon_plus.v104.retina.png");
  }
}
